#!/bin/bash

# This file is part of Clusterix, Copyright (C) 2004 Alessandro Manzini, 
# email: a.manzini@infogroup.it

# Clusterix is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# Clusterix is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Clusterix; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

case $1 in
start)
sh /opt/clusterix/gotest.sh &
;;
stop)
pid=$(ps auxw | grep gotest | grep -v grep | awk '{print $2}')
if [ ! -z "$pid" ]
then
kill -9 $pid
fi
;;
esac
